# imu

Defines a package to interact with IMUs.

## Getting Started

See the documentation [here](https://docs.kscale.dev/robot/imu) for instructions on getting started with this package.

## Development

Please make sure everything is `cargo fmt`'d and `cargo clippy`'d.

## Currently Supported IMUs

- [BNO055](./imu/bno055/README.md)
- [Hexmove](./imu/hexmove/README.md)
- [Hiwonder](./imu/hiwonder/README.md)
